==> ejc-invest-api-3.0.0-20250317.024922-10-sources.jar: com/ejianc/business/earlier/vo/EarlierProgressVO.java <==
package com.ejianc.business.earlier.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.earlier.vo.EarlierProgressDetailVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 前期手续一览
 * 
 * @author generator
 * 
 */
public class EarlierProgressVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private String description; // 描述
    private String finishState; // 是否完成(0:未完成-1:完成)
    private Long projectId; // 预立项项目id
    private String projectName; // 预立项项目名称
    private String projectCode; // 预立项项目编号
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private Date planBeginDate; // 计划开始日期
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private Date planFinishDate; // 计划结束日期
    private Integer projectCycleNum; // 项目周期
    private String engineeringTypeName; // 工程类型名称
    private String projectSetDepartmentName; // 立项部门名称
    private String projectManagementName; // 项目负责人名称
    private String projectOverview; // 工程概况
    private BigDecimal totalInvestmentScale; // 总投资规模
    private String stage; // 阶段(0:汇总1:报审2:调整报审)
    private String progress; // 进展(0:内部进行中1:外部进行中2:完成)
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private Date actualFinishDate; // 最新跟踪日期
    private String workListName; // 工作清单手续项
    private List<EarlierProgressDetailVO> earlierProgressDetailList = new ArrayList<>(); // 项目前期手续


    public Date getPlanBeginDate() {
        return planBeginDate;
    }

    public void setPlanBeginDate(Date planBeginDate) {
        this.planBeginDate = planBeginDate;
    }

    public Date getPlanFinishDate() {
        return planFinishDate;
    }

    public void setPlanFinishDate(Date planFinishDate) {
        this.planFinishDate = planFinishDate;
    }

    public Integer getProjectCycleNum() {
        return projectCycleNum;
    }

    public void setProjectCycleNum(Integer projectCycleNum) {
        this.projectCycleNum = projectCycleNum;
    }

    public String getEngineeringTypeName() {
        return engineeringTypeName;
    }

    public void setEngineeringTypeName(String engineeringTypeName) {
        this.engineeringTypeName = engineeringTypeName;
    }

    public String getProjectSetDepartmentName() {
        return projectSetDepartmentName;
    }

    public void setProjectSetDepartmentName(String projectSetDepartmentName) {
        this.projectSetDepartmentName = projectSetDepartmentName;
    }

    public String getProjectManagementName() {
        return projectManagementName;
    }

    public void setProjectManagementName(String projectManagementName) {
        this.projectManagementName = projectManagementName;
    }

    public String getProjectOverview() {
        return projectOverview;
    }

    public void setProjectOverview(String projectOverview) {
        this.projectOverview = projectOverview;
    }

    public BigDecimal getTotalInvestmentScale() {
        return totalInvestmentScale;
    }

    public void setTotalInvestmentScale(BigDecimal totalInvestmentScale) {
        this.totalInvestmentScale = totalInvestmentScale;
    }

    public String getStage() {
        return stage;
    }

    public void setStage(String stage) {
        this.stage = stage;
    }

    public String getProgress() {
        return progress;
    }

    public void setProgress(String progress) {
        this.progress = progress;
    }

    public Date getActualFinishDate() {
        return actualFinishDate;
    }

    public void setActualFinishDate(Date actualFinishDate) {
        this.actualFinishDate = actualFinishDate;
    }

    public String getWorkListName() {
        return workListName;
    }

    public void setWorkListName(String workListName) {
        this.workListName = workListName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public String getFinishState() {
        return finishState;
    }

    public void setFinishState(String finishState) {
        this.finishState = finishState;
    }
    @ReferSerialTransfer(referCode="invest_project_set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    
     public List<EarlierProgressDetailVO> getEarlierProgressDetailList() {
        return earlierProgressDetailList;
     }

     public void setEarlierProgressDetailList(List<EarlierProgressDetailVO> earlierProgressDetailList) {
        this.earlierProgressDetailList = earlierProgressDetailList;
     }
}

==> ejc-invest-api-3.0.0-20250403.064622-16-sources.jar: com/ejianc/business/earlier/vo/EarlierProgressVO.java <==
package com.ejianc.business.earlier.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.earlier.vo.EarlierProgressDetailVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 前期手续一览
 * 
 * @author generator
 * 
 */
public class EarlierProgressVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private String updateUserName; // 修改者
    private String description; // 描述
    private String finishState; // 是否完成(0:未完成-1:完成)
    private Long projectId; // 预立项项目id
    private String projectName; // 预立项项目名称
    private String projectCode; // 预立项项目编号
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private Date planBeginDate; // 计划开始日期
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private Date planFinishDate; // 计划结束日期
    private Integer projectCycleNum; // 项目周期
    private String engineeringTypeName; // 工程类型名称
    private String projectSetDepartmentName; // 立项部门名称
    private String projectManagementName; // 项目负责人名称
    private String projectOverview; // 工程概况
    private BigDecimal totalInvestmentScale; // 总投资规模
    private String stage; // 阶段(0:汇总1:报审2:调整报审)
    private String progress; // 进展(0:内部进行中1:外部进行中2:完成)
    @JsonFormat(
            shape = JsonFormat.Shape.STRING,
            pattern = "yyyy-MM-dd",
            timezone = "GMT+8"
    )
    private Date actualFinishDate; // 最新跟踪日期
    private String workListName; // 工作清单手续项
    private List<EarlierProgressDetailVO> earlierProgressDetailList = new ArrayList<>(); // 项目前期手续
    private String finishProgress; //完成进展

    public String getFinishProgress() {
        return finishProgress;
    }

    public void setFinishProgress(String finishProgress) {
        this.finishProgress = finishProgress;
    }

    public Date getPlanBeginDate() {
        return planBeginDate;
    }

    public void setPlanBeginDate(Date planBeginDate) {
        this.planBeginDate = planBeginDate;
    }

    public Date getPlanFinishDate() {
        return planFinishDate;
    }

    public void setPlanFinishDate(Date planFinishDate) {
        this.planFinishDate = planFinishDate;
    }

    public Integer getProjectCycleNum() {
        return projectCycleNum;
    }

    public void setProjectCycleNum(Integer projectCycleNum) {
        this.projectCycleNum = projectCycleNum;
    }

    public String getEngineeringTypeName() {
        return engineeringTypeName;
    }

    public void setEngineeringTypeName(String engineeringTypeName) {
        this.engineeringTypeName = engineeringTypeName;
    }

    public String getProjectSetDepartmentName() {
        return projectSetDepartmentName;
    }

    public void setProjectSetDepartmentName(String projectSetDepartmentName) {
        this.projectSetDepartmentName = projectSetDepartmentName;
    }

    public String getProjectManagementName() {
        return projectManagementName;
    }

    public void setProjectManagementName(String projectManagementName) {
        this.projectManagementName = projectManagementName;
    }

    public String getProjectOverview() {
        return projectOverview;
    }

    public void setProjectOverview(String projectOverview) {
        this.projectOverview = projectOverview;
    }

    public BigDecimal getTotalInvestmentScale() {
        return totalInvestmentScale;
    }

    public void setTotalInvestmentScale(BigDecimal totalInvestmentScale) {
        this.totalInvestmentScale = totalInvestmentScale;
    }

    public String getStage() {
        return stage;
    }

    public void setStage(String stage) {
        this.stage = stage;
    }

    public String getProgress() {
        return progress;
    }

    public void setProgress(String progress) {
        this.progress = progress;
    }

    public Date getActualFinishDate() {
        return actualFinishDate;
    }

    public void setActualFinishDate(Date actualFinishDate) {
        this.actualFinishDate = actualFinishDate;
    }

    public String getWorkListName() {
        return workListName;
    }

    public void setWorkListName(String workListName) {
        this.workListName = workListName;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }
    public String getFinishState() {
        return finishState;
    }

    public void setFinishState(String finishState) {
        this.finishState = finishState;
    }
    @ReferSerialTransfer(referCode="invest_project_set")
    public Long getProjectId() {
        return projectId;
    }
    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    
     public List<EarlierProgressDetailVO> getEarlierProgressDetailList() {
        return earlierProgressDetailList;
     }

     public void setEarlierProgressDetailList(List<EarlierProgressDetailVO> earlierProgressDetailList) {
        this.earlierProgressDetailList = earlierProgressDetailList;
     }
}
